@@ -117,7 +117,7 @@ class SpecificChord(Cached):
     def __hash__(self): return hash(self.key)
 
     def __sub__(self, other: SpecificChord) -> int:
-        return sum(abs(l - r) for l, r in zip(self, other))
+        return sum(abs(l - r) for l, r in zip(self, other, strict=True))
 
     def __add__(self, other: int) -> SpecificChord:
         """transpose"""
@@ -164,3 +164,6 @@ class SpecificChord(Cached):
             return mid
         mid.save(path)
         return None
+
+    def __getnewargs_ex__(self):
+        return (self.notes,), {'root': self.root}
