@@ -2,6 +2,7 @@ from __future__ import annotations
 
 import itertools
 import random
+from collections.abc import Sequence
 from typing import Type
 from typing import TypeVar
 from typing import no_type_check
@@ -208,11 +209,14 @@ class NoteSet(Cached):
         </div>
         """
 
+    def __getnewargs_ex__(self):
+        return (self.notes,), {'root': self.root}
+
 
 CHROMATIC_NOTESET = NoteSet(frozenset(config.chromatic_notes))
 
 
-class NoteRange:
+class NoteRange(Sequence[SpecificNote]):
     def __init__(
         self,
         start: SpecificNote | str,
@@ -243,6 +247,12 @@ class NoteRange:
         elif -len(self) <= item < 0: return self.noteset.add_note(self.stop, item + 1)
         else: raise IndexError('index out of range')
 
+    @overload
+    def __getitem__(self, i: int) -> SpecificNote: ...
+
+    @overload
+    def __getitem__(self, s: slice) -> NoteRange: ...
+
     def __getitem__(self, item: int | slice) -> SpecificNote | NoteRange:
         if isinstance(item, int): return self._getitem_int(item)
         elif isinstance(item, slice):
@@ -251,8 +261,12 @@ class NoteRange:
             return NoteRange(self._getitem_int(item.start), self._getitem_int(item.stop), self.noteset)
         else: raise TypeError(f'NoteRange indices must be integers or slices, got {type(item)}')
 
+    def __contains__(self, item: object) -> bool:
+        if not isinstance(item, SpecificNote):
+            return False
+        return item.abstract in self.noteset and self.start <= item <= self.stop
+
     def __iter__(self): return (self[i] for i in range(len(self)))
-    def __contains__(self, item: SpecificNote) -> bool: return item.abstract in self.noteset and self.start <= item <= self.stop
     def __repr__(self): return f'NoteRange({self.start}, {self.stop}, noteset={self.noteset})'
     def __len__(self): return self.noteset.subtract(self.stop, self.start) + 1
     def __eq__(self, other): return self._key == other._key
